==> tine20-allinone_2020.08.8.tar.bz2: Crm/js/Crm-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Wszystkie zapytania"

, "Default Lead List"
: "Domyślna lista zapytań"

, "The default list for new leads"
: "Domyślna lista dla nowych zapytań"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Poziom, na którym ma nastąpić powiadomienie o wykonaniu akcji"

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Domyślne ulubione"

, "The default favorite which is loaded on crm startup"
: "Domyślne ulubione zapytanie ładowane przy uruchamianiu Crm"

, "New Lead"
: "Nowe zapytanie"

, "Tags"
: "Znaczniki"

, "Lead name"
: "Nazwa zapytania"

, "Responsible"
: "Osoba odpowiedzialna"

, "Partner"
: "Wspólnik"

, "Customer"
: "Klient"

, "Leadstate"
: "Status zapytania"

, "Leadtype"
: "Typ zapytania"

, "Leadsource"
: "Źródło zapytania"

, "Probability"
: "Prawdopodobieństwo"

, "Turnover"
: "Obroty"

, "Estimated end"
: "Szacowane zakończenie"

, "Probable Turnover"
: "Prawdopodobny zwrot"

, "Resubmission Date"
: "Data ponowienia"

, "Import leads"
: ""

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM"

, "Tasks"
: "Zadania"

, "No Tasks to display"
: "Brak zadań"

, "Summary"
: "Streszczenie"

, "Add a task..."
: "Dodaj zadanie…"

, "Due Date"
: "Termin"

, "Priority"
: "Priorytet"

, "Percent"
: "W procentach"

, "Status"
: "Status"

, "Organizer"
: "Notes"

, "Add new {0}"
: "Dodaj {0}"

, "Unlink {0}"
: "Usuń {0}"

, "Unlink selected {0}"
: "Usuń zaznaczony {0}"

, "Edit {0}"
: "Edytuj \"{0}\""

, "Edit selected {0}"
: "Edytuj zaznaczone {0}"

, "Please choose the Lead to add the contacts to"
: "Proszę wybrać zapytanie, do którego należy dodać kontakty"

, "Please select the attenders' role"
: "Proszę wybrać rolę uczestnika"

, "Lead, Leads"
: [
  "Zapytanie"
 ,"zapytania"
 ,"zapytania"
 ,"zapytania"

]
, "Select Lead"
: "Wybierz zapytanie"

, "Role"
: "Rola"

, "Select Role"
: "Wybierz rolę"

, "Adding {0} contacts to lead"
: "Dodaję {0} kontakty do zapytania"

, "Phone"
: "Telefon"

, "Mobile"
: "Komórka"

, "Fax"
: "Faks"

, "E-Mail"
: "E-mail"

, "Web"
: "WWW"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Początek"

, "Change type to Customer"
: "Zmień typ na wartość: Klient"

, "Change type to Responsible"
: "Zmień typ na wartość: Osoba odpowiedzialna"

, "Change type to Partner"
: "Zmień typ na wartość: Wspólnik"

, "Change contact type"
: "Zmień typ kontaktu"

, "Search for Contacts to add ..."
: "Znajdź kontakty do dodania ..."

, "Name"
: "Nazwa"

, "Address"
: "Adres"

, "Data"
: "Dane dot. zapytania"

, "Cellphone"
: "Komórka"

, "End"
: "Koniec"

, "You do not have the run right for the Tasks application or it is not activated."
: "Brak uprawnień do uruchomienia aplikacji Zadania albo jest ona nieaktywna"

, "Products"
: "Produkty"

, "You do not have the run right for the Sales application or it is not activated."
: "Brak uprawnień do uruchomienia aplikacji Sprzedaż albo jest ona nieaktywna"

, "Enter lead name"
: ""

, "Expected turnover"
: "Oczekiwany obrót"

, "Description"
: "Opis"

, "Enter description"
: "Wprowadź opis"

, "lead list, lead lists"
: [
  "Lista zapytań"
 ,"listy zapytań"
 ,"listy zapytań"
 ,"listy zapytań"

]
, "lead lists"
: "listy zapytań"

, "Quick Search"
: "Szybkie wyszukiwanie"

, "Last Modified Time"
: "Czas ostatniej zmiany"

, "Last Modified By"
: "Ostatnio zmienione przez"

, "Creation Time"
: "Utworzono"

, "Created By"
: "Utworzone przez"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Produkt"

, "Price"
: "Cena"

, "Quantity"
: "Ilość"

, "Search for Products to add ..."
: "Znajdź produkty do dodania ..."

, "All leads I have read grants for"
: "Wszystkie zapytania, które mam prawo czytać"

, "Last modified by me"
: "Ostatnio zmienione przeze mnie"

, "All leads that I have last modified"
: "Wszystkie zapytania, które ostatnio zmieniłem/-am"

, "My leads"
: "Moje zapytania"

, "All leads that I am responsible for"
: "Wszystkie zapytania, za które odpowiadam"

, "Leads with overdue tasks"
: "Zapytania z zaległymi zadaniami"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "otwarte"

, "contacted"
: "kontakt nawiązany"

, "waiting for feedback"
: "oczekiwanie na odpowiedź"

, "quote sent"
: "kwota wysłana"

, "accepted"
: "zaakceptowane"

, "lost"
: "stracone"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Dystrybutor"

, "Enabled Features"
: "Aktywne funkcje"

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Kraj"

, "Source"
: "Źródło"

, "Scheduled end"
: "Planowane zakończenie"

, "Folder"
: "Katalog"

, "Updated by"
: "Zaktualizowane przez"

, "Updated Fields:"
: "Zaktualizowane pola:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Zapytanie %s zostało zmienione"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Zapytanie %s zostało utworzone"

, "Task"
: "Zadanie"

, "Lead Data"
: "Dane dot. zapytania"

, "End Scheduled"
: "Planowany koniec"

, "Contacts"
: "Kontakty"

, "Telephone"
: "Telefon"

, "Email"
: "E-mail"

, "low"
: "niski"

, "normal"
: "normalny"

, "high"
: "wysoki"

, "urgent"
: "pilny"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "edytowanie wspólnych katalogów zapytań"

, "Create new shared lead folders"
: "Utwórz nowe, wspólne katalogi zapytań"

, "manage shared leads favorites"
: "zarządzanie ulubionymi, wspólnymi zapytaniami"

, "Create or update shared leads favorites"
: "Utwórz albo uaktualnij ulubione, wspólne zapytania"




, "Lead"
: "Zapytanie"

, "lead list"
: "Lista zapytań"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Klient"

, "Partner"
: "Wspólnik"

, "Phone"
: "Telefon"

, "Mobile"
: "Komórka"

, "Fax"
: "Faks"

, "E-Mail"
: "E-mail"

, "Web"
: "WWW"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Status"

, "Start"
: "Początek"

, "Estimated end"
: "Szacowane zakończenie"

, "Leadtype"
: "Typ zapytania"

, "Leadsource"
: "Źródło zapytania"

, "Tags"
: "Znaczniki"

, "Lead name"
: "Nazwa zapytania"

, "Responsible"
: "Osoba odpowiedzialna"

, "Leadstate"
: "Status zapytania"

, "Probability"
: "Prawdopodobieństwo"

, "Turnover"
: "Obroty"

, "End"
: "Koniec"

, "Probable Turnover"
: "Prawdopodobny zwrot"

, "Resubmission Date"
: "Data ponowienia"

, "Import leads"
: ""

, "Add new {0}"
: "Dodaj {0}"

, "Unlink {0}"
: "Usuń {0}"

, "Unlink selected {0}"
: "Usuń zaznaczony {0}"

, "Edit {0}"
: "Edytuj \"{0}\""

, "Edit selected {0}"
: "Edytuj zaznaczone {0}"

, "New Lead"
: "Nowe zapytanie"

, "Products"
: "Produkty"

, "Product"
: "Produkt"

, "Description"
: "Opis"

, "Price"
: "Cena"

, "Quantity"
: "Ilość"

, "Search for Products to add ..."
: "Znajdź produkty do dodania ..."

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: "Zadania"

, "You do not have the run right for the Tasks application or it is not activated."
: "Brak uprawnień do uruchomienia aplikacji Zadania albo jest ona nieaktywna"

, "You do not have the run right for the Sales application or it is not activated."
: "Brak uprawnień do uruchomienia aplikacji Sprzedaż albo jest ona nieaktywna"

, "Lead, Leads"
: [
  "Zapytanie"
 ,"zapytania"
 ,"zapytania"
 ,"zapytania"

]
, "Enter lead name"
: ""

, "Expected turnover"
: "Oczekiwany obrót"

, "Enter description"
: "Wprowadź opis"

, "lead list, lead lists"
: [
  "Lista zapytań"
 ,"listy zapytań"
 ,"listy zapytań"
 ,"listy zapytań"

]
, "lead lists"
: "listy zapytań"

, "Quick Search"
: "Szybkie wyszukiwanie"

, "Last Modified Time"
: "Czas ostatniej zmiany"

, "Last Modified By"
: "Ostatnio zmienione przez"

, "Creation Time"
: "Utworzono"

, "Created By"
: "Utworzone przez"

, "X Lead"
: ""

, "read-only"
: ""

, "Archived"
: ""

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM"

, "Change type to Customer"
: "Zmień typ na wartość: Klient"

, "Change type to Responsible"
: "Zmień typ na wartość: Osoba odpowiedzialna"

, "Change type to Partner"
: "Zmień typ na wartość: Wspólnik"

, "Change contact type"
: "Zmień typ kontaktu"

, "Search for Contacts to add ..."
: "Znajdź kontakty do dodania ..."

, "Name"
: "Nazwa"

, "Address"
: "Adres"

, "Data"
: "Dane dot. zapytania"

, "Cellphone"
: "Komórka"

, "Role"
: "Rola"

, "Please choose the Lead to add the contacts to"
: "Proszę wybrać zapytanie, do którego należy dodać kontakty"

, "Please select the attenders' role"
: "Proszę wybrać rolę uczestnika"

, "Select Lead"
: "Wybierz zapytanie"

, "Select Role"
: "Wybierz rolę"

, "Adding {0} contacts to lead"
: "Dodaję {0} kontakty do zapytania"

, "No Tasks to display"
: "Brak zadań"

, "Summary"
: "Streszczenie"

, "Add a task..."
: "Dodaj zadanie…"

, "Due Date"
: "Termin"

, "Priority"
: "Priorytet"

, "Percent"
: "W procentach"

, "Organizer"
: "Notes"

, "All leads"
: "Wszystkie zapytania"

, "Default Lead List"
: "Domyślna lista zapytań"

, "The default list for new leads"
: "Domyślna lista dla nowych zapytań"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Poziom, na którym ma nastąpić powiadomienie o wykonaniu akcji"

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: "Domyślne ulubione"

, "The default favorite which is loaded on crm startup"
: "Domyślne ulubione zapytanie ładowane przy uruchamianiu Crm"

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "otwarte"

, "contacted"
: "kontakt nawiązany"

, "waiting for feedback"
: "oczekiwanie na odpowiedź"

, "quote sent"
: "kwota wysłana"

, "accepted"
: "zaakceptowane"

, "lost"
: "stracone"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Dystrybutor"

, "Enabled Features"
: "Aktywne funkcje"

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: "Dane dot. zapytania"

, "End Scheduled"
: "Planowany koniec"

, "Contacts"
: "Kontakty"

, "Telephone"
: "Telefon"

, "Email"
: "E-mail"

, "low"
: "niski"

, "normal"
: "normalny"

, "high"
: "wysoki"

, "urgent"
: "pilny"

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: "Zadanie"

, "State"
: "Kraj"

, "Source"
: "Źródło"

, "Scheduled end"
: "Planowane zakończenie"

, "Folder"
: "Katalog"

, "Updated by"
: "Zaktualizowane przez"

, "Updated Fields:"
: "Zaktualizowane pola:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Zapytanie %s zostało zmienione"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Zapytanie %s zostało utworzone"

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: "Wszystkie zapytania, które mam prawo czytać"

, "Last modified by me"
: "Ostatnio zmienione przeze mnie"

, "All leads that I have last modified"
: "Wszystkie zapytania, które ostatnio zmieniłem/-am"

, "My leads"
: "Moje zapytania"

, "All leads that I am responsible for"
: "Wszystkie zapytania, za które odpowiadam"

, "Leads with overdue tasks"
: "Zapytania z zaległymi zadaniami"

, "manage shared lead folders"
: "edytowanie wspólnych katalogów zapytań"

, "Create new shared lead folders"
: "Utwórz nowe, wspólne katalogi zapytań"

, "manage shared leads favorites"
: "zarządzanie ulubionymi, wspólnymi zapytaniami"

, "Create or update shared leads favorites"
: "Utwórz albo uaktualnij ulubione, wspólne zapytania"




, "Lead"
: "Zapytanie"

, "lead list"
: "Lista zapytań"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
